@@ -42,6 +42,15 @@ def instrument_declarative(cls, registry, metadata):
 def has_inherited_table(cls):
     """Given a class, return True if any of the classes it inherits from has a
     mapped table, otherwise return False.
+
+    This is used in declarative mixins to build attributes that behave
+    differently for the base class vs. a subclass in an inheritance
+    hierarchy.
+
+    .. seealso::
+
+        :ref:`decl_mixin_inheritance`
+
     """
     for class_ in cls.__mro__[1:]:
         if getattr(class_, '__table__', None) is not None:
@@ -196,19 +205,16 @@ class declared_attr(interfaces._MappedAttribute, property):
         Below, both MyClass as well as MySubClass will have a distinct
         ``id`` Column object established::
 
-            class HasSomeAttribute(object):
+            class HasIdMixin(object):
                 @declared_attr.cascading
-                def some_id(cls):
+                def id(cls):
                     if has_inherited_table(cls):
-                        return Column(
-                            ForeignKey('myclass.id'), primary_key=True)
+                        return Column(ForeignKey('myclass.id'), primary_key=True)
                     else:
                         return Column(Integer, primary_key=True)
 
-                    return Column('id', Integer, primary_key=True)
-
-            class MyClass(HasSomeAttribute, Base):
-                ""
+            class MyClass(HasIdMixin, Base):
+                __tablename__ = 'myclass'
                 # ...
 
             class MySubClass(MyClass):
@@ -301,6 +307,9 @@ def declarative_base(bind=None, metadata=None, mapper=None, cls=object,
       compatible callable to use as the meta type of the generated
       declarative base class.
 
+    .. versionchanged:: 1.1 if :paramref:`.declarative_base.cls` is a single class (rather
+         than a tuple), the constructed base class will inherit its docstring.
+
     .. seealso::
 
         :func:`.as_declarative`
@@ -317,6 +326,9 @@ def declarative_base(bind=None, metadata=None, mapper=None, cls=object,
     class_dict = dict(_decl_class_registry=class_registry,
                       metadata=lcl_metadata)
 
+    if isinstance(cls, type):
+        class_dict['__doc__'] = cls.__doc__
+
     if constructor:
         class_dict['__init__'] = constructor
     if mapper:
